import 'package:flutter/material.dart';

enum AnimationType { normal, fadeIn }

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions({
    required this.context,
    required this.child,
    this.animation = AnimationType.normal,
    this.duration = const Duration(seconds: 2),
    this.replacement = false,
  }) {
    switch (animation) {
      case AnimationType.normal:
        _normaltransition();
        break;
      case AnimationType.fadeIn:
        _fadeIntransition();
        break;
    }
  }

  void _pushPage(Route route) => Navigator.push(context, route);

  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  void _normaltransition() {
    final route = MaterialPageRoute(builder: (_) => child);
    if (replacement) {
      _pushReplacementPage(route);
    } else {
      _pushPage(route);
    }
  }

  void _fadeIntransition() {
    final route = PageRouteBuilder(
      pageBuilder: (_, __, ___) => child,
      transitionDuration: duration,
      transitionsBuilder: (_, animation, __, child) {
        return FadeTransition(
          child: child,
          opacity: Tween<double>(begin: 0, end: 1).animate(
            CurvedAnimation(parent: animation, curve: Curves.easeOut),
          ),
        );
      },
    );

    if (replacement) {
      _pushReplacementPage(route);
    } else {
      _pushPage(route);
    }
  }
}
